@@ -9,6 +9,7 @@ LAIRS_ROUTE = "lairs"
 WEBHOOKS = "webhooks"
 WORKSPACES_ROUTE = "workspaces"
 WORKSPACE_INTEGRATIONS_ROUTE = "workspace-integrations"
+TERMINAL_ROUTE = "terminal"
 
 
 
@@ -16,9 +17,13 @@ ROUTES = {
     "auth": {"refresh": f"{AUTH_ROUTE}/refresh"},
     "lairs": {"detail": f"{LAIRS_ROUTE}/$id"},
     "processes": { "detail_expanded": f"{PROCESSES_ROUTE}/$id/detail"},
+    "terminal": { "output": f"{TERMINAL_ROUTE}/output"},
     "webhooks": {"http_trigger_response": f"{WEBHOOKS}/http-trigger/response/$id"},
-    "workspaces": {"detail": f"{WORKSPACES_ROUTE}/$id"},
-    "workspace-integrations": {"detail": f"{WORKSPACE_INTEGRATIONS_ROUTE}/$id"}
+    "workspaces": {
+        "detail": f"{WORKSPACES_ROUTE}/$id",
+        "user_application_key_detail": f"{WORKSPACES_ROUTE}/$id/users/self",
+        },
+    "workspace-integrations": {"detail": f"{WORKSPACE_INTEGRATIONS_ROUTE}/$id"},
 }
 
 # origin is scheme + domain + port. explanation: https://stackoverflow.com/a/37366696/4293004
